pub struct Addresses {Show 13 fields
pub yield_bearing_ctf_exchange: &'static str,
pub yield_bearing_neg_risk_ctf_exchange: &'static str,
pub yield_bearing_neg_risk_adapter: &'static str,
pub yield_bearing_conditional_tokens: &'static str,
pub yield_bearing_neg_risk_conditional_tokens: &'static str,
pub ctf_exchange: &'static str,
pub neg_risk_ctf_exchange: &'static str,
pub neg_risk_adapter: &'static str,
pub conditional_tokens: &'static str,
pub neg_risk_conditional_tokens: &'static str,
pub usdt: &'static str,
pub kernel: &'static str,
pub ecdsa_validator: &'static str,
}Expand description
All contract addresses organized by contract type and chain
Fields
yield_bearing_ctf_exchange: &'static stryield_bearing_neg_risk_ctf_exchange: &'static stryield_bearing_neg_risk_adapter: &'static stryield_bearing_conditional_tokens: &'static stryield_bearing_neg_risk_conditional_tokens: &'static strctf_exchange: &'static strneg_risk_ctf_exchange: &'static strneg_risk_adapter: &'static strconditional_tokens: &'static strneg_risk_conditional_tokens: &'static strusdt: &'static strkernel: &'static strecdsa_validator: &'static strImplementations
Sourceimpl Addresses
impl Addresses
pub fn for_chain(chain_id: ChainId) -> Self
Sourcepub fn get_ctf_exchange(
&self,
is_yield_bearing: bool,
is_neg_risk: bool,
) -> &'static str
pub fn get_ctf_exchange( &self, is_yield_bearing: bool, is_neg_risk: bool, ) -> &'static str
Get the CTF Exchange address based on market type
Sourcepub fn get_conditional_tokens(
&self,
is_yield_bearing: bool,
is_neg_risk: bool,
) -> &'static str
pub fn get_conditional_tokens( &self, is_yield_bearing: bool, is_neg_risk: bool, ) -> &'static str
Get the Conditional Tokens address based on market type