pub struct OnchainClient { /* private fields */ }Expand description
On-chain client for Predict.fun operations
Implementations
Sourceimpl OnchainClient
impl OnchainClient
Sourcepub fn new(chain_id: ChainId, signer: PrivateKeySigner) -> Self
pub fn new(chain_id: ChainId, signer: PrivateKeySigner) -> Self
Create a new OnchainClient for direct EOA operations
Sourcepub fn with_predict_account(
chain_id: ChainId,
signer: PrivateKeySigner,
predict_account: &str,
) -> Result<Self>
pub fn with_predict_account( chain_id: ChainId, signer: PrivateKeySigner, predict_account: &str, ) -> Result<Self>
Create a new OnchainClient for Predict Account (smart wallet) operations
Sourcepub fn signer_address(&self) -> Address
pub fn signer_address(&self) -> Address
Get the signer address
Sourcepub fn trading_address(&self) -> Address
pub fn trading_address(&self) -> Address
Get the trading address (predict_account if set, otherwise signer)
Sourcepub fn is_smart_wallet(&self) -> bool
pub fn is_smart_wallet(&self) -> bool
Check if using smart wallet
Sourcepub async fn set_approvals(
&self,
is_neg_risk: bool,
is_yield_bearing: bool,
) -> Result<()>
pub async fn set_approvals( &self, is_neg_risk: bool, is_yield_bearing: bool, ) -> Result<()>
Set all necessary approvals for trading on the CTF Exchange.
This sets:
- ERC-1155
setApprovalForAllon Conditional Tokens → CTF Exchange (allows exchange to move outcome tokens on behalf of the trader) - ERC-20
approveon USDT → CTF Exchange (allows exchange to take USDT collateral)
For neg-risk markets, also approves the Neg Risk Adapter.
Sourcepub async fn split_positions(&self, options: SplitOptions) -> Result<String>
pub async fn split_positions(&self, options: SplitOptions) -> Result<String>