pub struct Order {
pub salt: String,
pub maker: String,
pub signer: String,
pub taker: String,
pub token_id: String,
pub maker_amount: String,
pub taker_amount: String,
pub expiration: String,
pub nonce: String,
pub fee_rate_bps: String,
pub side: Side,
pub signature_type: SignatureType,
}Expand description
Order structure matching predict.fun specification
Fields
salt: StringA unique salt to ensure entropy
maker: StringThe maker of the order, e.g. the order’s signer
signer: StringThe signer of the order
taker: StringThe address of the order taker. The zero address is used to indicate a public order
token_id: StringThe token ID of the CTF ERC-1155 asset to be bought or sold
maker_amount: StringThe maker amount
For a BUY order, this represents the total (price per asset * assets quantity) collateral (e.g. USDT) being offered.
For a SELL order, this represents the total amount of CTF assets being offered.
taker_amount: StringThe taker amount
For a BUY order, this represents the total amount of CTF assets to be received.
For a SELL order, this represents the total (price per asset * assets quantity) amount of collateral (e.g. USDT) to be received.
expiration: StringThe timestamp in seconds after which the order is expired
nonce: StringThe nonce used for on-chain cancellations
fee_rate_bps: StringThe fee rate, in basis points
side: SideThe side of the order, BUY (Bid) or SELL (Ask)
signature_type: SignatureTypeSignature type used by the Order (EOA also supports EIP-1271)